/*
 * Copyright 2009-2010 Nanjing RedOrange ltd (http://www.red-orange.cn)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package redora.client;

import redora.client.util.Field;

import java.util.HashMap;

/**
 * Light weight pojo to use in GWT client.
 * @author Nanjing RedOrange (www.red-orange.cn)
 */
public interface Persistable {
    enum Scope {
        /**
         * Usually all the records. The information is displayed in a single record
         * layout.
         */
        Form,
        /**
         * When records are shown in a table view, usually 5 to 10 attributes per
         * record line.
         */
        Table,
        /**
         * When displayed in a drop down list. You want to show one or two fields.
         * When a reference object is displayed, display only the List scoped
         * attributes.
         */
        List,
        /**
         * This scope will retrieve the missing attributes (those that are lazy and
         * not set type.
         */
        Lazy
    }
    Long getId();
    Scope scope();
    HashMap<Field, Object> dirty();
    String toListString();
}
